@@ -1,5 +1,7 @@
+from plone import api
 from zope.interface import implementer
 from zope.schema import Choice
+from zope.schema._bootstrapinterfaces import WrongType
 from zope.schema.interfaces import ConstraintNotSatisfied
 from zope.schema.interfaces import IChoice
 from zope.schema.interfaces import IFromUnicode
@@ -10,20 +12,20 @@ from zope.schema.vocabulary import VocabularyRegistryError
 @implementer(IChoice, IFromUnicode)
 class ChoicePlus(Choice):
     """A choice field, which allows additional terms.
-    Example: Allow new tags for catalog based vocabulary"""
-
-    allow_new = None
-
-    def __init__(self, values=None, vocabulary=None, source=None, **kw):
-        super(ChoicePlus, self).__init__(values, vocabulary, source, **kw)
-        self.allow_new = True
+    Example: Allow new tags for catalog based vocabulary.
+    """
 
     def _validate(self, value):
         # Pass all validations during initialization
         if self._init_field:
             return
 
-        super(Choice, self)._validate(value)
+        if self._type is not None and not isinstance(value, self._type):
+            raise WrongType(value, self._type, self.__name__)
+
+        if not self.constraint(value):
+            raise ConstraintNotSatisfied(value)
+
         vocabulary = self.vocabulary
         if vocabulary is None:
             vr = getVocabularyRegistry()
@@ -33,7 +35,7 @@ class ChoicePlus(Choice):
                 raise ValueError("Can't validate value without vocabulary")
 
         # The widget can control this attribute too
-        if self.allow_new:
+        if getattr(api.portal.getRequest(), 'allow_new', True):
             # Allow new values!
             return
         else:
